Isso – a commenting server similar to Disqus
============================================

## **English**

Isso – *Ich schrei sonst* – is a lightweight commenting server written in
Python and JavaScript. It aims to be a drop-in replacement for
[Disqus](http://disqus.com).

![Isso in Action](http://posativ.org/~tmp/isso-sample.png)

This project fork is **Isso** ( [github](https://github.com/posativ/isso),
[pypi](https://pypi.org/project/isso) ), which is suitable for China.
The new features of the environment, for ease of use, are now re-released to
pypi, renamed to **isso-cn** ( [github](https://github.com/staugur/isso-cn),
[pypi](https://pypi.org/project/isso-cn) ).

See [isso-cn.rtfd.vip](https://isso-cn.rtfd.vip) for more details.

## **中文**

Isso – 是一个使用Python和JavaScript编写的轻量级的评论服务，
它旨在成为 [Disqus](http://disqus.com) 的替代产品。

本项目fork自 **isso** （ [github](https://github.com/posativ/isso),
[pypi](https://pypi.org/project/isso) ），
增加了适合中国国内环境的新功能，为了方便使用，现在重新发布到pypi，
重命名为 **isso-cn** （ [github](https://github.com/staugur/isso-cn),
[pypi](https://pypi.org/project/isso-cn) ）。

详细文档请参考 [isso-cn.rtfd.vip](https://isso-cn.rtfd.vip)

> [![](https://open.saintic.com/rtfd/badge/isso-cn "文档构建状态")](https://isso-cn.rtfd.vip)
>
> 此仓库用以翻译isso中文文档，并增加一些适合国内环境的小功能，且会保持与原仓库代码更新合并。
>
> 1. 新评论微信提醒、审核，参考[文档-服务端-Wechat](https://isso-cn.rtfd.vip/zh_CN/latest/docs/configuration/server/#wechat)。
